@@ -3,8 +3,10 @@ import aiohttp
 from .errors import EmptyImage, InvalidToken, ServerError, TooManyRequests
 
 class Async_Trace:
-    """Tracemoe class with all the stuff"""
+
+    """Tracemoe class with all the stuff."""
     def __init__(self, api_token:str=""):
+        """Setup all urls and session."""
         self.base_url = "https://trace.moe/"
         self.media_url = "https://media.trace.moe/"
         self.api_token = api_token
@@ -20,7 +22,7 @@ class Async_Trace:
         url = f"{self.base_url}me"
         if self.api_token: url += f"?token={self.token}"
         return await self.aio_session.get(url).json()
-    
+
     async def search(self, path:str, encode:bool=True, is_url:bool=False) -> dict:
         """
         Args:
@@ -33,6 +35,7 @@ class Async_Trace:
            EmptyImage: Raised If Image Is empty
            InvalidToken: Raised when token provided Is Invalid
            ServerError: Raised If server Is having problem or Image Is malformed.
+           TooManyRequests: Raised when you are making too many requests
         """
         url = f"{self.base_url}api/search"
         if self.api_token:
@@ -89,7 +92,7 @@ class Async_Trace:
         """
         response = response["docs"][index]
         url = f'{self.media_url}video/{response["anilist_id"]}/'\
-              f'{response["filename"]}?t={response["at"]}&{token=response["tokenthumb"]}'
+              f'{response["filename"]}?t={response["at"]}&token={response["tokenthumb"]}'
         if mute:
             url += "&mute"
         return self.aio_session.get(url).content
