@@ -3,12 +3,14 @@ import requests
 from .errors import EmptyImage, InvalidToken, ServerError, TooManyRequests
 
 class TraceMoe:
-    """Tracemoe class with all the stuff"""
+
+    """Tracemoe class with all the stuff."""
     def __init__(self, api_token:str=""):
+        """Setup all vars."""
         self.base_url = "https://trace.moe/"
         self.media_url = "https://media.trace.moe/"
         self.api_token = api_token
-    
+
     def get_me(self) -> dict:
         """
         Lets you check the search quota and limit for your account (or IP address).
@@ -18,7 +20,7 @@ class TraceMoe:
         url = f"{self.base_url}me"
         if self.api_token: url += f"?token={self.token}"
         return requests.get(url).json()
-    
+
     def search(self, path:str, encode:bool=True, is_url:bool=False) -> dict:
         """
         Args:
@@ -31,6 +33,7 @@ class TraceMoe:
            EmptyImage: Raised If Image Is empty
            InvalidToken: Raised when token provided Is Invalid
            ServerError: Raised If server Is having problem or Image Is malformed.
+           TooManyRequests: Raised If you make too many requests to server.
         """
         url = f"{self.base_url}api/search"
         if self.api_token:
@@ -108,8 +111,6 @@ class TraceMoe:
         """
         response = response["docs"][index]
         url = f'{self.media_url}video/{response["anilist_id"]}/'\
-              f'{response["filename"]}?t={response["at"]}&{token=response["tokenthumb"]}'
+              f'{response["filename"]}?t={response["at"]}&token={response["tokenthumb"]}'
         if mute: url += "&mute"
         return requests.get(url).content
-        
-        
